@@ -12,6 +12,7 @@ import numpy as np
 import pandas as pd
 from itertools import chain
 from sklearn.metrics import r2_score
+from sklearn.base import is_classifier
 from .rank_function import features_rank_fnc
 from sklearn.metrics import mean_squared_error
 from sklearn.model_selection import train_test_split
@@ -34,12 +35,69 @@ def dev_predictions(estimator, X):
     return estimator.predict(X)
 
 
+def dev_score_roc(estimator, X, Y):
+    """
+    Calculates the area under the ROC curve score
+    for the DEV predictions.
+
+    Args:
+    estimator: linear model classifier object
+    X: a data frame of normalized values from developmental dataset
+    Y: a vector of sample labels from training data set
+
+    Yields:
+    float: AUC ROC score
+    """
+    if len(np.unique(Y)) > 2:
+        labels_pred = estimator.predict_proba(X)
+        kwargs = {'multi_class': 'ovr', "average": "weighted"}
+    else:
+        labels_pred = dev_predictions(estimator, X)
+        kwargs = {"average": "weighted"}
+    return roc_auc_score(Y, labels_pred, **kwargs)
+
+
+def dev_score_nmi(estimator, X, Y):
+    """
+    Calculates the normalized mutual information score
+    from the DEV predictions.
+
+    Args:
+    estimator: linear model classifier object
+    X: a data frame of normalized values from developmental dataset
+    Y: a vector of sample labels from training data set
+
+    Yields:
+    float: normalized mutual information score
+    """
+    labels_pred = dev_predictions(estimator, X)
+    return normalized_mutual_info_score(Y, labels_pred,
+                                        average_method='arithmetic')
+
+
+def dev_score_accuracy(estimator, X, Y):
+    """
+    Calculates the accuracy score from the DEV predictions.
+
+    Args:
+    estimator: linear model classifier object
+    X: a data frame of normalized values from developmental dataset
+    Y: a vector of sample labels from training data set
+
+    Yields:
+    float: accuracy score
+    """
+    labels_pred = dev_predictions(estimator, X)
+    return accuracy_score(Y, labels_pred)
+
+
 def dev_score_r2(estimator, X, Y):
     """
     Calculates the R2 score from the DEV predictions.
 
     Args:
     estimator: linear model regressor object
+    X: a data frame of normalized values from developmental dataset
     Y: a vector of sample labels from training data set
 
     Yields:
@@ -55,6 +113,7 @@ def dev_score_mse(estimator, X, Y):
 
     Args:
     estimator: linear model regressor object
+    X: a data frame of normalized values from developmental dataset
     Y: a vector of sample labels from training data set
 
     Yields:
@@ -70,6 +129,7 @@ def dev_score_evar(estimator, X, Y):
 
     Args:
     estimator: linear model regressor object
+    X: a data frame of normalized values from developmental dataset
     Y: a vector of sample labels from training data set
 
     Yields:
@@ -116,11 +176,18 @@ def regr_fe_step(estimator, X, Y, n_features_to_keep, features,
     rank = rank[::-1] # reverse sort
     selected = rank[0:n_features_to_keep]
     features_rank_fnc(features, rank, n_features_to_keep, fold, out_dir, RANK)
-    return {'n_features': X1.shape[1],
-            'r2_score': dev_score_r2(estimator, X2, Y2),
-            'mse_score': dev_score_mse(estimator, X2, Y2),
-            'explain_var': dev_score_evar(estimator, X2, Y2),
-            'selected': selected}
+    if is_classifier(estimator):
+        return {"n_features": X1.shape[1],
+                "nmi_score": dev_score_nmi(estimator, X2, Y2),
+                "accuracy_score": dev_score_accuracy(estimator, X2, Y2),
+                "roc_auc_score": dev_score_roc(estimator, X2, Y2),
+                "selected": selected}
+    else:
+        return {'n_features': X1.shape[1],
+                'r2_score': dev_score_r2(estimator, X2, Y2),
+                'mse_score': dev_score_mse(estimator, X2, Y2),
+                'explain_var': dev_score_evar(estimator, X2, Y2),
+                'selected': selected}
 
 
 def regr_fe(estimator, X, Y, n_features_iter, features, fold, out_dir,
@@ -129,7 +196,7 @@ def regr_fe(estimator, X, Y, n_features_iter, features, fold, out_dir,
     Iterate over features to by eliminated by step.
 
     Args:
-    estimator: regression linear model object
+    estimator: Non random forest classifier or regressor object
     X: a data frame of training data
     Y: a vector of sample labels from training data set
     n_features_iter: iterator for number of features to keep loop
@@ -148,7 +215,10 @@ def regr_fe(estimator, X, Y, n_features_iter, features, fold, out_dir,
     for nf in chain(n_features_iter, [1]):
         p = regr_fe_step(estimator, X, Y, nf, features, fold,
                          out_dir, dev_size, SEED, RANK)
-        yield p['n_features'], p['r2_score'], p['mse_score'], p['explain_var'], indices
+        if is_classifier(estimator):
+            yield p["n_features"], p["nmi_score"], p["accuracy_score"], p["roc_auc_score"], indices
+        else:
+            yield p['n_features'], p['r2_score'], p['mse_score'], p['explain_var'], indices
         indices = indices[p['selected']]
-        X = X[:, p['selected']]
+        X = X.iloc[:, p['selected']]
         features = features[p['selected']]
